==> cdktf_cdktf_provider_azurerm-0.5.58-py3-none-any.whl: package/lib/data-azurerm-data-share-dataset-data-lake-gen1.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzurermDataShareDatasetDataLakeGen1Config extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/data_share_dataset_data_lake_gen1#data_share_id DataAzurermDataShareDatasetDataLakeGen1#data_share_id}
    */
    readonly dataShareId: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/data_share_dataset_data_lake_gen1#name DataAzurermDataShareDatasetDataLakeGen1#name}
    */
    readonly name: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/data_share_dataset_data_lake_gen1#timeouts DataAzurermDataShareDatasetDataLakeGen1#timeouts}
    */
    readonly timeouts?: DataAzurermDataShareDatasetDataLakeGen1Timeouts;
}
export interface DataAzurermDataShareDatasetDataLakeGen1Timeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/data_share_dataset_data_lake_gen1#read DataAzurermDataShareDatasetDataLakeGen1#read}
    */
    readonly read?: string;
}
export declare function dataAzurermDataShareDatasetDataLakeGen1TimeoutsToTerraform(struct?: DataAzurermDataShareDatasetDataLakeGen1TimeoutsOutputReference | DataAzurermDataShareDatasetDataLakeGen1Timeouts | cdktf.IResolvable): any;
export declare class DataAzurermDataShareDatasetDataLakeGen1TimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): DataAzurermDataShareDatasetDataLakeGen1Timeouts | undefined;
    set internalValue(value: DataAzurermDataShareDatasetDataLakeGen1Timeouts | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/d/data_share_dataset_data_lake_gen1 azurerm_data_share_dataset_data_lake_gen1}
*/
export declare class DataAzurermDataShareDatasetDataLakeGen1 extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/d/data_share_dataset_data_lake_gen1 azurerm_data_share_dataset_data_lake_gen1} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzurermDataShareDatasetDataLakeGen1Config
    */
    constructor(scope: Construct, id: string, config: DataAzurermDataShareDatasetDataLakeGen1Config);
    get dataLakeStoreId(): string;
    private _dataShareId?;
    get dataShareId(): string;
    set dataShareId(value: string);
    get dataShareIdInput(): string | undefined;
    get displayName(): string;
    get fileName(): string;
    get folderPath(): string;
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _timeouts;
    get timeouts(): DataAzurermDataShareDatasetDataLakeGen1TimeoutsOutputReference;
    putTimeouts(value: DataAzurermDataShareDatasetDataLakeGen1Timeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): DataAzurermDataShareDatasetDataLakeGen1Timeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf_cdktf_provider_azurerm-0.6.16-py3-none-any.whl: package/lib/data-azurerm-data-share-dataset-data-lake-gen1.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzurermDataShareDatasetDataLakeGen1Config extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/data_share_dataset_data_lake_gen1#data_share_id DataAzurermDataShareDatasetDataLakeGen1#data_share_id}
    */
    readonly dataShareId: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/data_share_dataset_data_lake_gen1#name DataAzurermDataShareDatasetDataLakeGen1#name}
    */
    readonly name: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/data_share_dataset_data_lake_gen1#timeouts DataAzurermDataShareDatasetDataLakeGen1#timeouts}
    */
    readonly timeouts?: DataAzurermDataShareDatasetDataLakeGen1Timeouts;
}
export interface DataAzurermDataShareDatasetDataLakeGen1Timeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/data_share_dataset_data_lake_gen1#read DataAzurermDataShareDatasetDataLakeGen1#read}
    */
    readonly read?: string;
}
export declare function dataAzurermDataShareDatasetDataLakeGen1TimeoutsToTerraform(struct?: DataAzurermDataShareDatasetDataLakeGen1TimeoutsOutputReference | DataAzurermDataShareDatasetDataLakeGen1Timeouts | cdktf.IResolvable): any;
export declare class DataAzurermDataShareDatasetDataLakeGen1TimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataAzurermDataShareDatasetDataLakeGen1Timeouts | undefined;
    set internalValue(value: DataAzurermDataShareDatasetDataLakeGen1Timeouts | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/d/data_share_dataset_data_lake_gen1 azurerm_data_share_dataset_data_lake_gen1}
*/
export declare class DataAzurermDataShareDatasetDataLakeGen1 extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "azurerm_data_share_dataset_data_lake_gen1";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/d/data_share_dataset_data_lake_gen1 azurerm_data_share_dataset_data_lake_gen1} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzurermDataShareDatasetDataLakeGen1Config
    */
    constructor(scope: Construct, id: string, config: DataAzurermDataShareDatasetDataLakeGen1Config);
    get dataLakeStoreId(): string;
    private _dataShareId?;
    get dataShareId(): string;
    set dataShareId(value: string);
    get dataShareIdInput(): string | undefined;
    get displayName(): string;
    get fileName(): string;
    get folderPath(): string;
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _timeouts;
    get timeouts(): DataAzurermDataShareDatasetDataLakeGen1TimeoutsOutputReference;
    putTimeouts(value: DataAzurermDataShareDatasetDataLakeGen1Timeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): DataAzurermDataShareDatasetDataLakeGen1Timeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
